Stan Math Library: stan/math/rev/scal/fun/boost_isfinite.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
boost_isfinite.hpp File Reference
`#include <boost/math/special_functions/fpclassify.hpp>`
`#include <stan/math/rev/core.hpp>`

Go to the source code of this file.

## Namespaces
| boost
| Reimplementing boost functionality.
| boost::math
| Reimplmeneting boost functionality for `stan::math::var` and and bugs in classification of integer types.

## Functions
template<>
bool | boost::math::isfinite (const stan::math::var &v)
| Checks if the given number has finite value. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.